---
title: ":rotating_light: {{ env.workflow_name }}: failure"
---

The run `{{ env.run_id }}` of the workflow {{ env.workflow_name }} failed.

You can view the report here: https://github.com/{{ env.repository }}/actions/runs/{{ env.run_id }}

Pinging @nilearn/core
